@@ -1,5 +1,6 @@
 package Google::Adwords::Ad;
-use strict; use warnings;
+use strict;
+use warnings;
 
 use version; our $VERSION = qv('0.0.1');
 
@@ -38,7 +39,7 @@ my @fields = qw/
     prePriceAnnotation
     priceString
     productImage
-/;
+    /;
 
 __PACKAGE__->mk_accessors(@fields);
 
@@ -202,7 +203,7 @@ B<Accessors>
 Rohan Almeida <rohan@almeida.in>
  
  
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
 Copyright (c) 2006 Rohan Almeida <rohan@almeida.in>. All rights
 reserved.
